"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.execNull = exports.exec = exports.execLineWithoutLog = exports.create = void 0;
const util = require("util");
const child_process = require("child_process");
const environment_1 = require("./environment");
const debug_1 = require("./debug");
const promiseExec = util.promisify(child_process.exec);
const onFullFilledExec = (params) => {
  process.stdout.write(params.stdout);
  process.stderr.write(params.stderr);
};
const childOptions = { env: environment_1.env };

/** Creates a command line string by joining arguments. */
const create = (command, args) => {
  if (args.length) return [command].concat(args).join(" ");
  return command;
};
exports.create = create;

/** Runs a command line immediately & asynchronously without emitting log. */
const execLineWithoutLog = (line) => {
  return promiseExec(line, childOptions).then(
    (params) => onFullFilledExec(params),
    () => Promise.reject(`Command failed: ${line}`)
  );
};
exports.execLineWithoutLog = execLineWithoutLog;

/** Runs a command immediately & asynchronously. */
const exec = async (command, ...args) => {
  const line = exports.create(command, args);
  debug_1.traceRun(line);
  await exports.execLineWithoutLog(line);
  debug_1.traceDone(line);
};
exports.exec = exec;

/**
 * May be used as a placeholder instead of `exec()`.
 * Emits a debug log immediately and does nothing else.
 */
const execNull = (command, ...args) => {
  const line = exports.create(command, args);
  debug_1.traceRunDone(line);
  return Promise.resolve();
};
exports.execNull = execNull;
