"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCommandNames = exports.normalizeCommands = void 0;
const log_1 = require("../../log");
const line_1 = require("./line");
const command_1 = require("./command");

/** Normalizes the type of `command`. */
const normalizeCommand = (command) => {
  switch (typeof command) {
    case "string":
      return line_1.cmd(command);
    case "object":
      if (command_1.isMaybeCommand(command)) return command;
      break;
  }
  log_1.warn(`Not a command: ${command}`);
  return null;
};
const isNonNull = (x) => x !== null;

/** Normalizes the type of `commands`. */
const normalizeCommands = (commands) =>
  commands.map(normalizeCommand).filter(isNonNull);
exports.normalizeCommands = normalizeCommands;
const getCommandName = (command) => command.name;

/** Converts `commands` to a list of names. */
const getCommandNames = (commands) => commands.map(getCommandName);
exports.getCommandNames = getCommandNames;
