"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cmd = void 0;
const commandLine = require("../../command-line");
const debug_1 = require("../../debug");
const types_1 = require("../types");
const command_1 = require("./command");

/** `run()` method for `LineCommand`. */
const runUnit = function (onEvent) {
  const { line, name } = this;
  debug_1.traceRun(name);
  const startResult = onEvent(this, types_1.Event.Start);
  if (startResult) return startResult;
  return commandLine.execLineWithoutLog(line).then(
    () => {
      debug_1.traceDone(name);
      return onEvent(this, types_1.Event.Success);
    },
    (reason) =>
      onEvent(this, types_1.Event.Failure) ||
      (this.ignoresFailure ? Promise.resolve() : Promise.reject(reason))
  );
};

/** Creates a `Command` unit. */
const cmd = (command, ...args) => {
  const line = commandLine.create(command, args);
  const base = command_1.createCommand({
    name: line,
    run: runUnit,
    type: types_1.CommandType.Unit,
    subType: types_1.CommandSubType.CommandLine,
  });
  return Object.assign(base, { line });
};
exports.cmd = cmd;
