"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.nullCmd = void 0;
const commandLine = require("../../command-line");
const debug_1 = require("../../debug");
const types_1 = require("../types");
const command_1 = require("./command");

/**
 * `run()` method for `nullCmd()`.
 * Emits debug log and does nothing else.
 */
const runNull = function (onEvent) {
  debug_1.traceRunDone(this.name);
  onEvent(this, types_1.Event.Success);
  return Promise.resolve();
};

/**
 * May be used as a placeholder instead of `cmd()`.
 * Creates a `Command` that has no effect.
 */
const nullCmd = (...args) => {
  const line = commandLine.create("(null)", args);
  return command_1.createCommand({
    run: runNull,
    type: types_1.CommandType.Unit,
    subType: types_1.CommandSubType.Null,
    name: line,
  });
};
exports.nullCmd = nullCmd;
