"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.seq = void 0;
const debug_1 = require("../../debug");
const types_1 = require("../types");
const command_1 = require("./command");
const group_utility_1 = require("./group-utility");

/** `run()` method for `SequenceCommand`. */
const runSeq = function (onEvent) {
  let promiseChain = Promise.resolve();
  const startResult = onEvent(this, types_1.Event.Start);
  if (startResult) return startResult;
  for (const child of this.children)
    promiseChain = promiseChain.then(child.run.bind(child, onEvent));
  return promiseChain.then(
    () => onEvent(this, types_1.Event.Success),
    (reason) =>
      onEvent(this, types_1.Event.Failure) ||
      (this.ignoresFailure ? Promise.resolve() : Promise.reject(reason))
  );
};

/** Emits debug log. */
const inspectCommands = (commands) => {
  if (debug_1.logDebug) {
    debug_1.debug("prepare sequence:");
    debug_1.debugLines(group_utility_1.getCommandNames(commands), "  ");
  }
};

/** Creates a `Command` object that runs given commands in sequence. */
const seq = (...commands) => {
  const children = group_utility_1.normalizeCommands(commands);
  inspectCommands(children);
  const base = command_1.createCommand({
    run: runSeq,
    type: types_1.CommandType.Group,
    subType: types_1.CommandSubType.Sequence,
    name: "",
  });
  return Object.assign(base, { children });
};
exports.seq = seq;
