"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.countDescendants = void 0;
const log_1 = require("../../log");
const config_1 = require("../../config");
const types_1 = require("../types");
const traverse_1 = require("../tools/traverse");
const record_1 = require("./record");
const result_summary_1 = require("./result-summary");
const predicates_1 = require("./predicates");
const countDescendants = (topCommand) => {
  let numCommands = 0;
  const callback = (command) => {
    if (predicates_1.shouldCalc(command)) numCommands += 1;
    return false;
  };
  traverse_1.depthFirstSearch(topCommand, callback);
  return numCommands;
};
exports.countDescendants = countDescendants;

/**
 * Runs any `command` in a `try-catch` block.
 */
const run = async (command, onEvent, onSuccessAll, onFailureAny) => {
  const numTotal = exports.countDescendants(command);
  let numComplete = 0;
  const recorder = record_1.createRecorder();
  const recordEvent = (command, event) => {
    recorder.record(command, event);
    if (predicates_1.shouldCalc(command) && event === types_1.Event.Success)
      log_1.log(`done ${(numComplete += 1)} / ${numTotal}`);
    return undefined;
  };
  const eventHandler = onEvent
    ? (command, event) => {
        recordEvent(command, event);
        return onEvent(command, event);
      }
    : recordEvent;
  try {
    await command.run(eventHandler);
    if (onSuccessAll) onSuccessAll();
  } catch (e) {
    log_1.error(e);
    if (onFailureAny) onFailureAny();
  }
  if (config_1.resultSummaryType) {
    log_1.newLine();
    result_summary_1.renderResultSummary(command, recorder);
    log_1.newLine();
  }
  if (numComplete === numTotal) {
    const totalDuration = record_1.calcDurationSec(
      recorder.getHistory(command)
    );
    const totalDurationStr = totalDuration.toFixed(2);
    log_1.log(`Successfully completed. Maybe. (total ${totalDurationStr}s)\n`);
  }
  return recorder.historyMap;
};
exports.run = run;
